#!/usr/bin/env python
#--------------------------------------------------------------------------
#
# Name: split_jif
#
# Description:
#       This script splits an associated jitter product into its
#       constituent jitter exposures, with each exposure in a separate
#	output file.
#
# Usage:
#       % split_jif infile
#
# History:
# Date     OPR      Who         Reason
# -------- -------- ---------- ---------------------------------------------
# 08/14/06 xxxxx    MSwam      tool for STIS DMS associations processing
#--------------------------------------------------------------------------
#
from pyraf import iraf
from pyraf.irafglobals import *
import shutil
import os
import sys
import string
import glob
import opusutil
  
def split_jif(jifasn):
  primary_hdu = jifasn+"[0]"
  #
  # NEXTEND keywd will determine how many extensions to split out
  iraf.imgets(primary_hdu, "NEXTEND")
  nextend = iraf.imgets.value
  opusutil.PrintMsg('I',str(nextend)+" extensions found.")

  for extension in range(1,int(nextend)+1):
    extension_hdu = jifasn+"["+str(extension)+"]"
    #
    # EXPNAME keywd will determine output filename
    iraf.imgets(extension_hdu, "EXPNAME")
    expname             = string.lower(iraf.imgets.value)
    expname_jif         = expname+"_jif.fits"
    expname_jif_primary = expname_jif+"[0]"
    #
    opusutil.PrintMsg('I','copying ext '+str(extension)+" to "+expname)
    opusutil.RemoveIfThere(expname_jif)
    iraf.imcopy(primary_hdu, expname_jif, verbose=no)
    iraf.imcopy(jifasn+"[jit,"+str(extension)+",noinherit]",
                expname_jif+"[jit,1,inherit,append]", verbose=no)

    # update FILENAME, NEXTEND keywords
    iraf.hedit (expname_jif_primary, "FILENAME", expname_jif,
                verify=no, show=no, update=yes)
    iraf.hedit (expname_jif_primary, "NEXTEND", "1",
                add=no, delete=no, verify=no, show=no, update=yes)

#------------------------------------------------------------------------
#
# SPLIT_JIT
#
#-----------------------------------------------------------------------
#
for jifasn in glob.glob("*0_jif.fits"):
  #
  opusutil.PrintMsg('I','Splitting '+jifasn)
  split_jif(jifasn)

sys.exit(0)  

